@@ -94,7 +94,7 @@ void Worksheet::loginToSession()
         m_session->login();
 
         enableHighlighting(Settings::self()->highlightDefault());
-        enableTabCompletion(Settings::self()->tabCompletionDefault());
+        enableCompletion(Settings::self()->completionDefault());
         enableExpressionNumbering(Settings::self()->expressionNumberingDefault());
 #ifdef WITH_EPS
         session()->setTypesettingEnabled(Settings::self()->typesetDefault());
@@ -106,20 +106,61 @@ void Worksheet::loginToSession()
 
 }
 
+void Worksheet::print( QPrinter* printer )
+{
+    m_proxy->useHighResolution(true);
+    foreach(WorksheetEntry* e, m_entries)
+        e->updateResult();
+
+
+    KTextEdit::print(printer);
+
+    m_proxy->useHighResolution(false);
+    foreach(WorksheetEntry* e, m_entries)
+        e->updateResult();
+
+}
+
 bool Worksheet::event(QEvent* event)
 {
     if (event->type() == QEvent::ShortcutOverride)
     {
         QKeyEvent *e = static_cast<QKeyEvent *>( event );
-        //ignore the Shift+Return shortcut, so it can be used as a Shortcut for a KAction
+        //ignore the following shortcuts, so they can be used as a Shortcut for a KAction:
+        //Shift+Return
+        //Tab (only if completion is enabled)
+        //Shift+Delete
         if (e->modifiers() == Qt::ShiftModifier&&
             (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter))
         {
             e->ignore();
             return false;
+        }else if ( (e->modifiers()==Qt::ShiftModifier) && (e->key() == Qt::Key_Delete))
+        {
+            e->ignore();
+            return false;
+        }else
+        if ( e->key() == Qt::Key_Tab && m_completionEnabled )
+        {
+            WorksheetEntry* current=currentEntry();
+            // special tab handling here
+            if (current)
+            {
+                //get the current line of the entry. If it's empty, do a regular tab(indent),
+                //otherwise check for tab completion (if supported by the backend)
+                const QString line=current->currentLine(textCursor()).trimmed();
+
+                if(line.isEmpty())
+                {
+                    return KTextEdit::event(e);
+                }else
+                {
+                    e->ignore();
+                    return false;
+                }
+            }
         }
     }
-
     return KTextEdit::event(event);
 }
 
@@ -133,31 +174,6 @@ void Worksheet::keyPressEvent(QKeyEvent* event)
 
     QTimer::singleShot(0, this, SLOT(moveToClosestValidCursor()));
 
-    if ( event->key() == Qt::Key_Tab &&m_tabCompletionEnabled )
-    {
-        // special tab handling here
-        if (current)
-        {
-            //get the current line of the entry. If it's empty, do a regular tab(indent),
-            //otherwise check for tab completion (if supported by the backend)
-            const QString line=current->currentLine(textCursor()).trimmed();
-
-            if(line.isEmpty())
-            {
-                KTextEdit::keyPressEvent(event);
-            }else
-            {
-                Cantor::TabCompletionObject* tco=m_session->tabCompletionFor(line);
-                if(tco)
-                    current->setTabCompletion(tco);
-            }
-        }
-
-    }else
-    if ( (event->modifiers()==Qt::ShiftModifier) && (event->key() == Qt::Key_Delete)) //TODO: make configurable
-    {
-        removeCurrentEntry();
-    }else
     if ( (event->modifiers()==Qt::NoModifier) && (event->key() == Qt::Key_Enter ||event->key() == Qt::Key_Return))
     {
         //If the current Entry is showing a popup completion box,
@@ -165,7 +181,7 @@ void Worksheet::keyPressEvent(QKeyEvent* event)
         //otherwise, just do a normal Enter(line break)
         WorksheetEntry* entry=currentEntry();
         if(entry&&entry->isShowingCompletionPopup())
-            entry->applySelectedTabCompletion();
+            entry->applySelectedCompletion();
         else
             KTextEdit::keyPressEvent(event);
     }else
@@ -359,6 +375,22 @@ void Worksheet::evaluateCurrentEntry()
     if (entry->isInCommandCell(textCursor()))
     {
         evaluateEntry(entry);
+
+        if(Settings::self()->autoEval())
+        {
+            QList<WorksheetEntry*>::iterator it=m_entries.begin();
+            while((*it)!=entry&&it!=m_entries.end())
+                ++it;
+
+            it++;
+
+            for(;it!=m_entries.end();++it)
+            {
+                //kDebug()<<"evaluate"<<entry->command();
+                evaluateEntry(*it);
+            }
+        }
+
     }else if (entry->isInCurrentInformationCell(textCursor()))
     {
         entry->addInformation();
@@ -386,6 +418,24 @@ void Worksheet::evaluateEntry(WorksheetEntry* entry)
     emit modified();
 }
 
+void Worksheet::showCompletion()
+{
+    WorksheetEntry* current=currentEntry();
+    //get the current line of the entry. If it's empty, do a regular tab(indent),
+    //otherwise check for tab completion (if supported by the backend)
+    const QString line=current->currentLine(textCursor()).trimmed();
+
+    if(line.isEmpty())
+    {
+        return;
+    }else
+    {
+        Cantor::CompletionObject* tco=m_session->completionFor(line);
+        if(tco)
+            current->setCompletion(tco);
+    }
+}
+
 WorksheetEntry* Worksheet::currentEntry()
 {
     return entryAt(textCursor());
@@ -532,9 +582,9 @@ void Worksheet::enableHighlighting(bool highlight)
     }
 }
 
-void Worksheet::enableTabCompletion(bool enable)
+void Worksheet::enableCompletion(bool enable)
 {
-    m_tabCompletionEnabled=enable;
+    m_completionEnabled=enable;
 }
 
 Cantor::Session* Worksheet::session()
@@ -613,6 +663,67 @@ void Worksheet::savePlain(const QString& filename)
     file.close();
 }
 
+void Worksheet::saveLatex(const QString& filename,  bool exportImages)
+{
+    kDebug()<<"exporting to Latex: "<<filename;
+    kDebug()<<(exportImages ? "": "Not ")<<"exporting images";
+    QFile file(filename);
+    if(!file.open(QIODevice::WriteOnly))
+    {
+        KMessageBox::error(this, i18n("Error saving file %1", filename), i18n("Error - Cantor"));
+        return;
+    }
+
+    QTextStream stream(&file);
+
+    stream<<
+        "\\documentclass[a4paper,10pt,fleqn]{article}\n" \
+        "\\usepackage{fullpage}\n" \
+        "\\usepackage{graphicx}\n" \
+        "\\usepackage[utf8]{inputenc} \n"\
+        "\\usepackage{amsmath,amssymb} \n" \
+        "\n\n"\
+        "\\begin{document}\n";
+    stream<<endl;
+
+    foreach(WorksheetEntry * const entry, m_entries)
+    {
+        const QString& cmd=entry->command();
+
+        stream<<"\\noindent ";
+        stream<<QString(" { \\large \\bf \\begin{verbatim} %1 \\end{verbatim}  }\n\n").arg(cmd);
+
+        if(entry->expression()&&entry->expression()->result())
+            stream<<entry->expression()->result()->toLatex();
+
+        stream<<endl<<endl;
+    }
+
+    stream<<endl;
+    stream<<"\\end{document}\n";
+
+    file.close();
+
+    if(exportImages)
+    {
+        foreach( WorksheetEntry* entry, m_entries )
+        {
+            if ( entry->expression() )
+            {
+                Cantor::Result* result=entry->expression()->result();
+                if(!result)
+                    continue;
+                KUrl dest(filename);
+                dest.setFileName(result->url().fileName());
+                kDebug()<<"saving image to "<<dest;
+                if(result->type()==Cantor::ImageResult::Type||result->type()==Cantor::EpsResult::Type)
+                    result->save(dest.toLocalFile());
+            }
+        }
+    }
+
+}
+
 void Worksheet::load(const QString& filename )
 {
     // m_file is always local so we can use QFile on it
