@@ -26,7 +26,7 @@
 #include <expression.h>
 
 FunctionsModel::FunctionsModel(QObject *parent)
-	: QAbstractTableModel(parent), m_selectedRow(-1), m_resolution(500)
+	: QAbstractTableModel(parent), m_selectedRow(-1), m_resolution(500), m_fcount(1)
 {}
 
 QVariant FunctionsModel::data(const QModelIndex & index, int role) const
@@ -314,4 +314,9 @@ void FunctionsModel::setResolution(uint res)
 	}
 }
 
+QString FunctionsModel::freeId()
+{
+	return QString("f%1").arg(m_fcount++);
+}
+
 #include "functionsmodel.moc"
