@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -27,12 +27,16 @@
 #include "dictionary.h"
 #include "functionsmodel.h"
 #include "functionsview.h"
-#include "operatorsmodel.h"
 #include "askname.h"
+#include "value.h"
+#include "variablesdelegate.h"
+#include "viewportwidget.h"
 #ifdef HAVE_OPENGL
 #	include "graph3d.h"
 #endif
 
+#include <analitzagui/operatorsmodel.h>
+
 #include <QVBoxLayout>
 #include <QHeaderView>
 #include <QItemDelegate>
@@ -47,9 +51,11 @@
 #include <KStatusBar>
 #include <KLocale>
 #include <KStandardAction>
-#include "variablesdelegate.h"
+#include <KProcess>
+#include <KRecentFilesAction>
+#include <KApplication>
 
-KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
+KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 {
 	resize(900, 500);
 	
@@ -59,13 +65,19 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	setStatusBar(new KStatusBar(this));
 	setMenuBar(new KMenuBar(this));
 	
+	QMenu* g_menu = menuBar()->addMenu(i18n("Session"));
+	g_menu->addAction(KStandardAction::openNew(this, SLOT(newInstance()), this));
+	g_menu->addAction(KStandardAction::quit(this, SLOT(close()), this));
+	
 	m_status = new QLabel(this);
 	statusBar()->insertWidget(0, m_status);
+    menuBar()->addMenu("|")->setEnabled(false);
 	
-	///////Consola
-	QWidget *console = new QWidget(p);
+	///////Console
+	QWidget *console = new QWidget(tabs);
 	QVBoxLayout *c_layo = new QVBoxLayout(console);
-	c_results = new ConsoleHtml(this);
+	c_results = new ConsoleHtml(console);
+	c_results->view()->setFocusPolicy(Qt::NoFocus);
 	c_dock_vars = new QDockWidget(i18n("Variables"), this);
 	c_dock_vars->setFeatures(QDockWidget::DockWidgetFloatable|QDockWidget::DockWidgetMovable);
 	this->addDockWidget(Qt::RightDockWidgetArea, c_dock_vars);
@@ -82,6 +94,7 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	
 	c_exp = new ExpressionEdit(console);
 	c_exp->setAnalitza(c_results->analitza());
+	c_exp->setExamples(QStringList() << "square:=x->x**2" << "fib:=n->piecewise { eq(n,0)?0, eq(n,1)?1, ?fib(n-1)+fib(n-2) }");
 	c_dock_vars->setWidget(c_variables);
 	
 	tabs->addTab(console, i18n("&Console"));
@@ -93,27 +106,32 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	connect(c_results, SIGNAL(status(QString)), this, SLOT(changeStatusBar(QString)));
 	connect(c_results, SIGNAL(changed()), this, SLOT(updateInformation()));
 	connect(c_results, SIGNAL(changed()), c_exp, SLOT(updateCompleter()));
-	connect(c_variables, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(edit_var(QModelIndex)));
+	connect(c_results, SIGNAL(paste(QString)), c_exp, SLOT(insertText(QString)));
+	connect(c_variables, SIGNAL(clicked(QModelIndex)), this, SLOT(edit_var(QModelIndex)));
 	
 	////////menu
-	QMenu *c_menu = menuBar()->addMenu(i18n("C&onsole"));
+	c_menu = menuBar()->addMenu(i18n("C&onsole"));
 	
-	c_menu->addAction(KStandardAction::openNew(c_results, SLOT(clear()), this));
-	c_menu->addAction(KIcon("document-open"), i18nc("@item:inmenu", "&Load Script"),
+	c_menu->addAction(KIcon("document-open"), i18nc("@item:inmenu", "&Load Script..."),
 						this, SLOT(loadScript()), Qt::CTRL+Qt::Key_L);
-	c_menu->addAction(KIcon("document-save"), i18nc("@item:inmenu", "&Save Script"),
+	c_recentScripts=new KRecentFilesAction(KIcon("document-open-recent"), i18n("Recent Scripts"), this);
+	connect(c_recentScripts, SIGNAL(urlSelected(KUrl)), this, SLOT(loadScript(KUrl)));
+	c_menu->addAction(c_recentScripts);
+	
+	c_menu->addAction(KIcon("document-save"), i18nc("@item:inmenu", "&Save Script..."),
 						this, SLOT(saveScript()), Qt::CTRL+Qt::Key_G);
-	c_menu->addAction(KIcon("document-save"), i18nc("@item:inmenu", "&Save Log"),
+	c_menu->addAction(KIcon("document-save"), i18nc("@item:inmenu", "&Export Log..."),
 						this, SLOT(saveLog()), QKeySequence::Save);
 	c_menu->addSeparator();
-	c_menu->addAction(KStandardAction::quit(this, SLOT(close()), this));
+	c_menu->addAction(KStandardAction::clear(c_results, SLOT(clear()), this));
+	initializeRecentScripts();
 	////////////
 	//////EOConsola
 	
 	//////2D Graph
 	b_funcsModel=new FunctionsModel(this);
 	
-	m_graph2d = new Graph2D(b_funcsModel, this);
+	m_graph2d = new Graph2D(b_funcsModel, tabs);
 	
 	b_dock_funcs = new QDockWidget(i18n("Functions"), this);
 	b_tools = new QTabWidget(b_dock_funcs);
@@ -130,7 +148,7 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	b_tools->addTab(b_funcs, i18n("List"));
 	
 	b_funced = new FunctionEdit(b_tools);
-	b_funced->setVariables(new Variables);
+	b_funced->setVariables(new Analitza::Variables);
 	connect(b_funced, SIGNAL(accept()), this, SLOT(new_func()));
 	b_tools->addTab(b_funced, KIcon("list-add"), i18n("&Add"));
 	
@@ -142,10 +160,13 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	b_varsView->horizontalHeader()->setStretchLastSection(true);
 	b_varsView->setSelectionBehavior(QAbstractItemView::SelectRows);
 	b_varsView->setContextMenuPolicy(Qt::CustomContextMenu);
-	b_tools->addTab(b_varsView, i18n("Variables"));
-	
 	VariablesDelegate* delegate=new VariablesDelegate(b_varsView);
 	b_varsView->setItemDelegate(delegate);
+	b_tools->addTab(b_varsView, i18n("Variables"));
+	
+	ViewportWidget* b_viewport = new ViewportWidget(this);
+	b_viewport->setViewport(m_graph2d->definedViewport());
+	b_tools->addTab(b_viewport, i18n("Viewport"));
 	
 	b_dock_funcs->setWidget(b_tools);
 	b_dock_funcs->setFeatures(QDockWidget::DockWidgetFloatable | QDockWidget::DockWidgetMovable);
@@ -155,18 +176,22 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	connect(b_funcs, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(edit_func(const QModelIndex &)));
 	connect(b_tools, SIGNAL(currentChanged(int)), this, SLOT(functools(int)));
 	connect(m_graph2d, SIGNAL(status(const QString &)), this, SLOT(changeStatusBar(const QString &)));
+	connect(m_graph2d, SIGNAL(viewportChanged(QRectF)), b_viewport, SLOT(setViewport(QRectF)));
+	connect(b_viewport, SIGNAL(viewportChange(QRectF)), m_graph2d, SLOT(setViewport(QRectF)));
 	connect(b_varsView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(varsContextMenu(QPoint)));
 	
 	////////menu
-	QMenu *b_menu = menuBar()->addMenu(i18n("2&D Graph"));
+	b_menu = menuBar()->addMenu(i18n("2&D Graph"));
 	QAction* b_actions[6];
 	b_actions[0] = b_menu->addAction(i18n("&Grid"), this, SLOT(toggleSquares()));
 	b_actions[1] = b_menu->addAction(i18n("&Keep Aspect Ratio"), this, SLOT(toggleKeepAspect()));
+	b_menu->addAction(KStandardAction::save(this, SLOT(saveGraph()), this));
+	b_menu->addSeparator();
 	b_menu->addAction(KStandardAction::zoomIn(m_graph2d, SLOT(zoomIn()), this));
 	b_menu->addAction(KStandardAction::zoomOut(m_graph2d, SLOT(zoomOut()), this));
-	b_menu->addSeparator();
-	b_menu->addAction(KStandardAction::save(this, SLOT(saveGraph()), this));
-	b_menu->addAction(KIcon("zoom-original"), i18n("&Reset View"), m_graph2d, SLOT(resetViewport()));
+	KAction* ac=KStandardAction::actualSize(m_graph2d, SLOT(resetViewport()), this);
+	ac->setShortcut(Qt::ControlModifier + Qt::Key_0);
+	b_menu->addAction(ac);
 	b_menu->addSeparator()->setText(i18n("Resolution"));
 	b_actions[2] = b_menu->addAction(i18nc("@item:inmenu", "Poor"), this, SLOT(set_res_low()));
 	b_actions[3] = b_menu->addAction(i18nc("@item:inmenu", "Normal"), this, SLOT(set_res_std()));
@@ -188,13 +213,16 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	b_actions[3]->setChecked(true);
 	b_actions[4]->setCheckable(true);
 	b_actions[5]->setCheckable(true);
+	set_res_std();
 	//////EO2D Graph
 	
 	/////3DGraph
 #ifdef HAVE_OPENGL
-	QWidget *tridim = new QWidget(p);
+	QWidget *tridim = new QWidget(tabs);
 	QVBoxLayout *t_layo = new QVBoxLayout(tridim);
 	t_exp = new ExpressionEdit(tridim);
+	t_exp->setExamples(QStringList() << "sin x+sin y" << "(x,y)->x" << "x*y");
+	t_exp->setAns("x");
 	m_graph3d = new Graph3D(tridim);
 	
 	tridim->setLayout(t_layo);
@@ -206,7 +234,7 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	connect(m_graph3d, SIGNAL(status(const QString &)), this, SLOT(changeStatusBar(const QString &)));
 	
 	////////menu
-	QMenu *t_menu = menuBar()->addMenu(i18n("3D &Graph"));
+	t_menu = menuBar()->addMenu(i18n("3D &Graph"));
 	QAction* t_actions[5];
 	t_actions[0] = t_menu->addAction(i18n("&Transparency"), this, SLOT(toggleTransparency()));
 	t_menu->addAction(KStandardAction::save(this, SLOT(save3DGraph()), this));
@@ -229,6 +257,7 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 #endif
 	////////////
 	//////EO3D Graph
+    menuBar()->addMenu("|")->setEnabled(false);
 	
 	//Dictionary tab
 	d_dock = new QDockWidget(i18n("Operations"), this);
@@ -242,7 +271,8 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	d_filter=new KLineEdit(w);
 	d_filter->setClearButtonShown(true);
 	d_filter->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
-	connect(d_filter, SIGNAL(textChanged(const QString&)), dic, SLOT(filterChanged(const QString&)));
+	connect(d_filter, SIGNAL(textChanged(const QString&)), dic, SLOT(setFilter(const QString&)));
+	connect(d_filter, SIGNAL(textChanged(const QString&)), this, SLOT(dictionaryFilterChanged(const QString&)));
 	d_list = new QListView(w);
 	d_list->setModel(dic->model());
 	d_list->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding));
@@ -251,29 +281,55 @@ KAlgebra::KAlgebra(QWidget *p) : KMainWindow(p)
 	leftLayo->addWidget(d_list);
 	d_dock->setWidget(w);
 	
-	connect(d_list->selectionModel(), SIGNAL(currentChanged ( const QModelIndex &, const QModelIndex & )),
-		dic, SLOT(activated(const QModelIndex& , const QModelIndex& )));
+	connect(d_list->selectionModel(), SIGNAL(currentChanged (QModelIndex, QModelIndex)),
+		dic, SLOT(activated(QModelIndex , QModelIndex)));
 	
 	//EODictionary
 	//Ego's reminder
 	menuBar()->addMenu(helpMenu());
 	
-	connect(b_funcsModel, SIGNAL(functionModified(const QString &, const Expression & )),
-			c_results, SLOT(modifyVariable(const QString & , const Expression & )));
-	connect(b_funcsModel, SIGNAL(functionRemoved(const QString &)),
-			c_results, SLOT(removeVariable(const QString &)));
+	connect(b_funcsModel, SIGNAL(functionModified(QString, Expression)),
+			c_results, SLOT(modifyVariable(QString, Expression)));
+	connect(b_funcsModel, SIGNAL(functionRemoved(QString)),
+			c_results, SLOT(removeVariable(QString)));
 	
 	connect(tabs, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
 	tabChanged(0);
 }
 
+KAlgebra::~KAlgebra()
+{
+	KConfig conf("kalgebrarc");
+	KConfigGroup config(&conf, "Default");
+	QStringList urls;
+	foreach(const KUrl& url, c_recentScripts->urls())
+		urls += url.prettyUrl();
+	
+	config.writeEntry("recent", urls);
+}
+
+void KAlgebra::initializeRecentScripts()
+{
+	KConfig conf("kalgebrarc");
+	KConfigGroup config(&conf, "Default");
+	
+	QStringList urls=config.readEntry("recent", QStringList());
+	foreach(const QString& url, urls) {
+		c_recentScripts->addUrl(KUrl(url));
+	}
+}
+
+void KAlgebra::newInstance()
+{
+	KProcess::startDetached(QApplication::applicationFilePath());
+}
+
 void KAlgebra::new_func()
 {
-	QString name = b_funced->name();
-	function f(b_funced->name(), Expression(b_funced->text(), b_funced->isMathML()), b_funced->variables(), b_funced->color());
+	function f=b_funced->createFunction();
 	
 	if(b_funced->editing()) {
-		b_funcsModel->editFunction(name, f);
+		b_funcsModel->editFunction(f.name(), f);
 	} else {
 		b_funcsModel->addFunction(f);
 	}
@@ -281,7 +337,7 @@ void KAlgebra::new_func()
 	b_funced->setEditing(false);
 	b_funced->clear();
 	b_tools->setCurrentIndex(0);
-	b_funcsModel->setSelected(name);
+	b_funcsModel->setSelected(f.name());
 	m_graph2d->setFocus();
 }
 
@@ -290,7 +346,7 @@ void KAlgebra::edit_func(const QModelIndex &idx)
 	b_tools->setTabText(1, i18n("&Editing"));
 	b_tools->setCurrentIndex(1);
 	b_funced->setName(b_funcsModel->data(idx.sibling(idx.row(), 0)).toString());
-	b_funced->setText(b_funcsModel->data(idx.sibling(idx.row(), 1)).toString());
+	b_funced->setFunction(b_funcsModel->data(idx.sibling(idx.row(), 1)).toString());
 	b_funced->setEditing(true);
 	b_funced->setFocus();
 }
@@ -300,7 +356,7 @@ void KAlgebra::functools(int i)
 	if(i==0)
 		b_tools->setTabText(1, i18n("&Add"));
 	else {
-		b_funced->setName(QString("f").append(QString::number(b_funcsModel->rowCount()+1)));
+		b_funced->setName(b_funcsModel->freeId());
 		b_funced->setEditing(false);
 		b_funced->setFocus();
 	}
@@ -308,21 +364,27 @@ void KAlgebra::functools(int i)
 
 void KAlgebra::edit_var(const QModelIndex &idx)
 {
-	QModelIndex idxName=idx.sibling(idx.row(), 0);
-	VarEdit e(this, false);
-	QString var = c_variables->model()->data(idxName, Qt::DisplayRole).toString();
-	
-	e.setAnalitza(c_results->analitza());
-	e.setVar(var);
-	
-	if(e.exec() == QDialog::Accepted)
-		c_results->analitza()->insertVariable(var, e.val());
+	if(idx.column()==0) {
+		c_exp->insertText(idx.data().toString());
+	} else {
+		QModelIndex idxName=idx.sibling(idx.row(), 0);
+		VarEdit e(this, false);
+		QString var = c_variables->model()->data(idxName, Qt::DisplayRole).toString();
+		
+		e.setAnalitza(c_results->analitza());
+		e.setName(var);
+		
+		if(e.exec() == QDialog::Accepted) {
+			QString str=var+" := "+e.val().toString();
+			c_results->addOperation(Analitza::Expression(str, false), str);
+		}
+	}
 }
 
 void KAlgebra::operate()
 {
 	if(!c_exp->text().isEmpty()){
-		c_exp->setCorrect(c_results->addOperation(c_exp->text(), c_exp->isMathML()));
+		c_exp->setCorrect(c_results->addOperation(c_exp->expression(), c_exp->toPlainText()));
 		c_exp->selectAll();
 	}
 }
@@ -335,34 +397,47 @@ void KAlgebra::changeStatusBar(const QString& msg)
 
 void KAlgebra::loadScript()
 {
-	QString path = KFileDialog::getOpenFileName(KUrl(), "*.kal|"+i18n("Script (*.kal)"), this, i18n("Choose a script"));
+	KUrl path = KFileDialog::getOpenUrl(KUrl(), "*.kal|"+i18n("Script (*.kal)"), this, i18n("Choose a script"));
+	
 	if(!path.isEmpty())
-		c_results->loadScript(path);
+		loadScript(path);
+}
+
+void KAlgebra::loadScript(const KUrl& path)
+{
+	bool loaded=c_results->loadScript(path);
+	
+	if(loaded)
+		c_recentScripts->addUrl(path);
 }
 
 void KAlgebra::saveScript()
 {
-	QString path = KFileDialog::getSaveFileName(KUrl(), "*.kal|"+i18n("Script (*.kal)"), this);
+	KUrl path = KFileDialog::getSaveUrl(KUrl(), "*.kal|"+i18n("Script (*.kal)"), this);
+	bool loaded=false;
 	if(!path.isEmpty())
-		c_results->saveScript(path);
+		loaded=c_results->saveScript(path);
+	
+	if(loaded)
+		c_recentScripts->addUrl(path);
 }
 
 void KAlgebra::saveLog()
 {
-	QString path = KFileDialog::getSaveFileName(KUrl(), "*|"+i18n("Text File (*)"),  this);
+	KUrl path = KFileDialog::getSaveUrl(KUrl(), "*.html|"+i18n("HTML File (*.html)"),  this);
 	if(!path.isEmpty())
 		c_results->saveLog(path);
 }
 
-void KAlgebra::set_res_low()	{ m_graph2d->setResolution(416); }
-void KAlgebra::set_res_std()	{ m_graph2d->setResolution(832); }
-void KAlgebra::set_res_fine()	{ m_graph2d->setResolution(1664);}
-void KAlgebra::set_res_vfine()	{ m_graph2d->setResolution(3328);}
+void KAlgebra::set_res_low()	{ b_funcsModel->setResolution(416); }
+void KAlgebra::set_res_std()	{ b_funcsModel->setResolution(832); }
+void KAlgebra::set_res_fine()	{ b_funcsModel->setResolution(1664);}
+void KAlgebra::set_res_vfine()	{ b_funcsModel->setResolution(3328);}
 
 void KAlgebra::new_func3d()
 {
 #ifdef HAVE_OPENGL
-	m_graph3d->setFunc(Expression(t_exp->text(), t_exp->isMathML()));
+	m_graph3d->setFunc(t_exp->expression());
 	m_graph3d->setFocus();
 #endif
 }
@@ -426,13 +501,22 @@ void KAlgebra::tabChanged(int n)
 	c_dock_vars->hide();
 	b_dock_funcs->hide();
 	d_dock->hide();
+	
+	c_menu->setEnabled(false);
+	b_menu->setEnabled(false);
+	t_menu->setEnabled(false);
+	
+	m_status->clear();
+	
 	switch(n) {
 		case 0:
+			c_menu->setEnabled(true);
 			c_dock_vars->show();
 			c_dock_vars->raise();
 			c_exp->setFocus();
 			break;
 		case 1:
+			b_menu->setEnabled(true);
 			b_dock_funcs->show();
 			b_dock_funcs->raise();
 			
@@ -442,6 +526,7 @@ void KAlgebra::tabChanged(int n)
 			break;
 #ifdef HAVE_OPENGL
 		case 2:
+			t_menu->setEnabled(true);
 			t_exp->setFocus();
 			break;
 #endif
@@ -483,8 +568,14 @@ void KAlgebra::varsContextMenu(const QPoint& p)
 		AskName a(i18n("Enter a name for the new variable"), 0);
 		
 		if(a.exec()==QDialog::Accepted)
-			b_varsModel->insertVariable(a.name(), Expression(Cn(0)));
+			b_varsModel->insertVariable(a.name(), Analitza::Expression(Analitza::Cn(0)));
 	}
 }
 
+void KAlgebra::dictionaryFilterChanged(const QString&)
+{
+	if(d_list->model()->rowCount()==1)
+		d_list->setCurrentIndex(d_list->model()->index(0,0));
+}
+
 #include "kalgebra.moc"
