@@ -19,18 +19,19 @@ sed -e "s/\([0-9].*[a-z]\)//" < data/cnames.dat | sed 's/^[A-B] //' | \
 grep ^C data/cnames.dat | awk '{ print "i18nc( \"Sky Culture\", \"" $2 "\" );" }' >> "kstars_i18n.cpp"
 
 # extract cities
-awk 'BEGIN {FS=":"}; {print "\"" $1 "\""; }' < data/Cities.dat | \
-   sed 's/ *\"$/\");/g' | sed 's/^\" */i18nc(\"City name (optional, probably does not need a translation)\",\"/g' | sed 's/i18nc(.*,"");//' >> "cities.tmp"
+awk 'BEGIN {FS=":"}; {print "\"" $2 ":" $3 ":" $1 "\""; }' < data/Cities.dat | \
+   sed 's/ *:/:/g' | \
+   sed 's/ *\"$/\");/g' | sed 's/^\" */i18nc(\"City in /' | sed 's/ *: */ /' | sed 's/ *: */\",\"/' | sed 's/i18nc(.*,"");//' >> "cities.tmp"
 sort --unique cities.tmp >> kstars_i18n.cpp
 
 # extract regions
-awk 'BEGIN {FS=":"}; {print "\"" $2 "\""; }' < data/Cities.dat | \
-   sed 's/ *\"$/\");/g' | sed 's/^\" */i18nc(\"Region\/state name (optional, rarely needs a translation)\",\"/g' | sed 's/i18nc(.*,"");//' >> "regions.tmp";
+awk 'BEGIN {FS=":"}; {print "\"" $3 ":" $2 "\""; }' < data/Cities.dat | \
+   sed 's/ *\"$/\");/g' | sed 's/^\" */i18nc(\"Region\/state in /' | sed 's/ *: */\",\"/g' | sed 's/i18nc(.*,"");//' >> "regions.tmp";
 sort --unique regions.tmp >> kstars_i18n.cpp
 
 # extract countries
 awk 'BEGIN {FS=":"}; {print "\"" $3 "\""; }' < data/Cities.dat | \
-   sed 's/ *\"$/\");/g' | sed 's/^\" */i18nc(\"Country name (optional, but should be translated)\",\"/g' | sed 's/i18nc(.*,"");//' >> "countries.tmp"
+   sed 's/ *\"$/\");/g' | sed 's/^\" */i18nc(\"Country name\",\"/g' | sed 's/i18nc(.*,"");//' >> "countries.tmp"
 sort --unique countries.tmp >> kstars_i18n.cpp
 
 # extract image/info menu items
@@ -66,9 +67,9 @@ rm -f image_url.tmp
 rm -f info_url.tmp
 rm -f tips.cpp
 
-$EXTRACTRC xplanet/*.ui *.ui tools/*.ui dialogs/*.ui fitsviewer/*.ui indi/*.ui options/*.ui *.rc >> rc.cpp || exit 11
+$EXTRACTRC xplanet/*.ui *.ui tools/*.ui dialogs/*.ui fitsviewer/*.ui indi/*.ui options/*.ui comast/*.ui *.rc >> rc.cpp || exit 11
 (cd data && $PREPARETIPS > ../tips.cpp)
-$XGETTEXT *.cpp *.h tools/*.cpp tools/*.h skycomponents/*.cpp widgets/*.cpp dialogs/*.cpp dialogs/*.h fitsviewer/*.cpp fitsviewer/*.h indi/*.cpp indi/*.h options/*.cpp options/*.h skyobjects/*.cpp skyobjects/*.h xplanet/*.cpp -o $podir/kstars.pot
+$XGETTEXT *.cpp *.h tools/*.cpp tools/*.h skycomponents/*.cpp widgets/*.cpp dialogs/*.cpp dialogs/*.h fitsviewer/*.cpp fitsviewer/*.h indi/*.cpp indi/*.h options/*.cpp options/*.h skyobjects/*.cpp skyobjects/*.h xplanet/*.cpp comast/*.h comast/*.cpp -o $podir/kstars.pot
 rm -f tips.cpp
 rm -f kstars_i18n.cpp
 rm -f rc.cpp
