@@ -8,7 +8,6 @@
 
 #include "SpatialGeneral.h"
 #include "RangeConvex.h"
-#include "Htmio.h"
 
 
 #define N(n)	index_->nodes_[(n)]
@@ -1256,12 +1255,3 @@ RangeConvex::testVectorInside(const SpatialVector & v0,
   return true;
 }
 
-
-/////////////<<///////////////////////////////////////////
-// write to ostream
-//
-std::ostream& operator <<( std::ostream& out, const RangeConvex & c) {
-  Htmio::write(out, c);
-  return(out);
-}
-
