@@ -34,15 +34,20 @@
 
 QStringList CustomCatalogComponent::m_Columns = QString( "ID RA Dc Tp Nm Mg Mj Mn PA Ig" ).split( ' ', QString::SkipEmptyParts );
 
-CustomCatalogComponent::CustomCatalogComponent(SkyComponent *parent, const QString &fname, bool showerrs, int index) : ListComponent(parent), m_Filename( fname ), m_Showerrs( showerrs ), m_ccIndex(index)
+CustomCatalogComponent::CustomCatalogComponent(SkyComposite *parent, const QString &fname, bool showerrs, int index) :
+    ListComponent(parent),
+    m_Filename( fname ),
+    m_Showerrs( showerrs ),
+    m_ccIndex(index)
 {
+    loadData();
 }
 
 CustomCatalogComponent::~CustomCatalogComponent()
 {
 }
 
-void CustomCatalogComponent::init( KStarsData * ) {
+void CustomCatalogComponent::loadData() {
     emitProgressText( i18n("Loading custom catalog: %1", m_Filename ) );
 
     QDir::setCurrent( QDir::homePath() );  //for files with relative path
@@ -98,24 +103,24 @@ void CustomCatalogComponent::init( KStarsData * ) {
             }
         }
 
-        if ( objectList().size() ) {
+        if ( m_ObjectList.size() ) {
             if ( errs.size() > 0 ) { //some data parsed, but there are errs to report
                 QString message( i18n( "Some lines in the custom catalog could not be parsed; see error messages below." ) + '\n' +
                                  i18n( "To reject the file, press Cancel. " ) +
                                  i18n( "To accept the file (ignoring unparsed lines), press Accept." ) );
                 if ( KMessageBox::warningContinueCancelList( 0, message, errs,
                         i18n( "Some Lines in File Were Invalid" ), KGuiItem( i18n( "Accept" ) ) ) != KMessageBox::Continue ) {
-                    objectList().clear();
+                    m_ObjectList.clear();
                     return ;
                 }
             }
-        } else { //objList.count() == 0
+        } else {
             if ( m_Showerrs ) {
                 QString message( i18n( "No lines could be parsed from the specified file, see error messages below." ) );
                 KMessageBox::informationList( 0, message, errs,
                                               i18n( "No Valid Data Found in File" ) );
             }
-            objectList().clear();
+            m_ObjectList.clear();
             return;
         }
 
@@ -128,10 +133,11 @@ void CustomCatalogComponent::init( KStarsData * ) {
     }
 }
 
-void CustomCatalogComponent::update( KStarsData *data, KSNumbers * )
+void CustomCatalogComponent::update( KSNumbers * )
 {
-    if ( visible() ) {
-        foreach ( SkyObject *obj, objectList() ) {
+    if ( selected() ) {
+        KStarsData *data = KStarsData::Instance();
+        foreach ( SkyObject *obj, m_ObjectList ) {
             obj->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         }
     }
@@ -139,7 +145,7 @@ void CustomCatalogComponent::update( KStarsData *data, KSNumbers * )
 
 void CustomCatalogComponent::draw( QPainter &psky )
 {
-    if ( ! visible() ) return;
+    if ( ! selected() ) return;
 
     SkyMap *map = SkyMap::Instance();
     //    float Width  = map->scale() * map->width();
@@ -149,21 +155,21 @@ void CustomCatalogComponent::draw( QPainter &psky )
     psky.setPen( QColor( m_catColor ) );
 
     //Draw Custom Catalog objects
-    foreach ( SkyObject *obj, objectList() ) {
+    foreach ( SkyObject *obj, m_ObjectList ) {
 
         if ( map->checkVisibility( obj ) ) {
             QPointF o = map->toScreen( obj );
 
-            if ( ! map->onScreen( o ) ) continue;
+            if( ! map->onScreen( o ) )
+                continue;
 
             if ( obj->type()==0 ) {
                 StarObject *starobj = (StarObject*)obj;
                 float zoomlim = 7.0 + ( Options::zoomFactor()/MINZOOM)/50.0;
                 float mag = starobj->mag();
                 float sizeFactor = 2.0;
-                int size = int( map->scale()*sizeFactor*(zoomlim - mag) ) + 1;
-                if (size>int(23*map->scale())) size=int(23*map->scale());
-                starobj->draw( psky, o.x(), o.y(), size, Options::starColorMode(), Options::starColorIntensity(), true );
+                int size = map->scale()*sizeFactor*(zoomlim - mag) + 1;
+                starobj->draw( psky, o, size );
             } else {
                 //PA for Deep-Sky objects is 90 + PA because major axis is horizontal at PA=0
                 DeepSkyObject *dso = (DeepSkyObject*)obj;
@@ -418,11 +424,11 @@ bool CustomCatalogComponent::processCustomDataLine(int lnum, const QStringList &
 
     if ( iType == 0 ) { //Add a star
         StarObject *o = new StarObject( RA, Dec, mag, lname );
-        objectList().append( o );
+        m_ObjectList.append( o );
     } else { //Add a deep-sky object
         DeepSkyObject *o = new DeepSkyObject( iType, RA, Dec, mag,
                                               name, QString(), lname, m_catPrefix, a, b, PA );
-        objectList().append( o );
+        m_ObjectList.append( o );
 
         //Add name to the list of object names
         if ( ! name.isEmpty() )
