@@ -41,7 +41,6 @@
 
 #include "Options.h"
 #include "kstarsdata.h"
-#include "ksutils.h"
 #include "skyobjects/skyobject.h"
 #include "skymap.h"
 
@@ -49,26 +48,25 @@
 #include "linelist.h"
 
 
-LineListIndex::LineListIndex( SkyComponent *parent, const QString& name )
-        : SkyComposite( parent ), m_name(name)
+LineListIndex::LineListIndex( SkyComposite *parent, const QString& name ) :
+    SkyComponent( parent ),
+    m_name(name)
 {
     m_skyMesh = SkyMesh::Instance();
     m_lineIndex = new LineListHash();
     m_polyIndex = new LineListHash();
-    m_lineIndexCnt = m_polyIndexCnt = 0;
 }
 
 // This is a callback for the indexLines() function below
-const IndexHash& LineListIndex::getIndexHash(LineList* lineList )
-{
+const IndexHash& LineListIndex::getIndexHash(LineList* lineList ) {
     return skyMesh()->indexLine( lineList->points() );
 }
 
 
 void LineListIndex::appendLine( LineList* lineList, int debug)
 {
-
-    if ( debug < skyMesh()->debug() ) debug = skyMesh()->debug();
+    if( debug < skyMesh()->debug() )
+        debug = skyMesh()->debug();
 
     const IndexHash& indexHash = getIndexHash( lineList );
     IndexHash::const_iterator iter = indexHash.constBegin();
@@ -76,16 +74,13 @@ void LineListIndex::appendLine( LineList* lineList, int debug)
         Trixel trixel = iter.key();
         iter++;
 
-        if ( ! lineIndex()->contains( trixel ) ) {
-            lineIndex()->insert(trixel, new LineListList() );
+        if ( ! m_lineIndex->contains( trixel ) ) {
+            m_lineIndex->insert(trixel, new LineListList() );
         }
-        lineIndex()->value( trixel )->append( lineList );
+        m_lineIndex->value( trixel )->append( lineList );
     }
 
     m_listList.append( lineList);
-
-    if ( debug > 9 )
-        printf("LineList: %3d: %d\n", ++m_lineIndexCnt, indexHash.size() );
 }
 
 void LineListIndex::appendPoly(LineList* lineList, int debug)
@@ -98,14 +93,11 @@ void LineListIndex::appendPoly(LineList* lineList, int debug)
         Trixel trixel = iter.key();
         iter++;
 
-        if ( ! polyIndex()->contains( trixel ) ) {
-            polyIndex()->insert( trixel, new LineListList() );
+        if ( ! m_polyIndex->contains( trixel ) ) {
+            m_polyIndex->insert( trixel, new LineListList() );
         }
-        polyIndex()->value( trixel )->append( lineList );
+        m_polyIndex->value( trixel )->append( lineList );
     }
-
-    if ( debug > 9 )
-        printf("PolyList: %3d: %d\n", ++m_polyIndexCnt, indexHash.size() );
 }
 
 void LineListIndex::appendBoth(LineList* lineList, int debug)
@@ -116,8 +108,6 @@ void LineListIndex::appendBoth(LineList* lineList, int debug)
 
 void LineListIndex::reindexLines()
 {
-    m_lineIndexCnt = 0;
-
     LineListHash* oldIndex = m_lineIndex;
     m_lineIndex = new LineListHash();
 
@@ -136,8 +126,9 @@ void LineListIndex::reindexLines()
 }
 
 
-void LineListIndex::JITupdate( KStarsData *data, LineList* lineList )
+void LineListIndex::JITupdate( LineList* lineList )
 {
+    KStarsData *data = KStarsData::Instance();
     lineList->updateID = data->updateID();
     SkyList* points = lineList->points();
 
@@ -163,10 +154,9 @@ void LineListIndex::preDraw( QPainter &psky )
 
 void LineListIndex::draw( QPainter &psky )
 {
-    if ( ! selected() ) return;
-
+    if ( ! selected() )
+        return;
     preDraw( psky );
-
     drawLines( psky );
 }
 
@@ -175,56 +165,42 @@ bool LineListIndex::skipAt( LineList *lineList, int i )
 {
     Q_UNUSED(lineList)
     Q_UNUSED(i)
-                                        // left this in .cpp because
-    return false;                      // it generates compiler warnings.
-}                                      // -jbb
+    return false;
+}
 
-
-// Yet another 2 callbacks.  These are used in LabeledListIndex
 void LineListIndex::updateLabelCandidates( const QPointF& /*o*/, LineList* /*lineList*/, int /*i*/ )
 {}
 
-void LineListIndex::updateLabelCandidates( const QPoint& /*o*/, LineList* /*lineList*/, int /*i*/ )
-{}
-
-
 void LineListIndex::drawAllLines( QPainter& psky )
 {
-    SkyMap *map = SkyMap::Instance();
-    KStarsData *data = KStarsData::Instance();
-    UpdateID updateID = data->updateID();
+    SkyMap* map = SkyMap::Instance();
+    UpdateID updateID = KStarsData::Instance()->updateID();
 
-    QPolygonF polyMW;
     bool isVisible, isVisibleLast;
-    SkyPoint  *pLast, *pThis;
-    QPointF oThis, oLast, oMid;
 
     for (int i = 0; i < m_listList.size(); i++) {
         LineList* lineList = m_listList.at( i );
 
         if ( lineList->updateID != updateID )
-            JITupdate( data, lineList );
+            JITupdate( lineList );
 
         SkyList* points = lineList->points();
-        pLast = points->first();
-        oLast = map->toScreen( pLast, true, &isVisibleLast );
+        SkyPoint* pLast = points->first();
+        QPointF oLast = map->toScreen( pLast, true, &isVisibleLast );
 
-        for ( int i = 1 ; i < points->size() ; i++ ) {
-            pThis = points->at( i );
-            oThis = map->toScreen( pThis, true, &isVisible );
-
-            if ( map->onScreen( oThis, oLast) && ! skipAt( lineList, i ) ) {
+        for ( int j = 1 ; j < points->size() ; j++ ) {
+            SkyPoint* pThis = points->at( j );
+            QPointF   oThis = map->toScreen( pThis, true, &isVisible );
 
+            if ( map->onScreen( oThis, oLast) && ! skipAt( lineList, j ) ) {
                 if ( isVisible && isVisibleLast ) {
                     psky.drawLine( oLast, oThis );
-                    updateLabelCandidates( oThis, lineList, i );
-                }
-                else if ( isVisibleLast ) {
-                    oMid = map->clipLineI( pLast, pThis );
+                    updateLabelCandidates( oThis, lineList, j );
+                } else if ( isVisibleLast ) {
+                    QPointF oMid = map->clipLineI( pLast, pThis );
                     psky.drawLine( oLast, oMid );
-                }
-                else if ( isVisible ) {
-                    oMid = map->clipLineI( pThis, pLast );
+                } else if ( isVisible ) {
+                    QPointF oMid = map->clipLineI( pThis, pLast );
                     psky.drawLine( oMid, oThis );
                 }
             }
@@ -240,54 +216,47 @@ void LineListIndex::drawAllLines( QPainter& psky )
 void LineListIndex::drawLines( QPainter& psky )
 {
     SkyMap *map = SkyMap::Instance();
-    KStarsData *data = KStarsData::Instance();
+    DrawID   drawID   = skyMesh()->drawID();
+    UpdateID updateID = KStarsData::Instance()->updateID();
 
-    DrawID drawID = skyMesh()->drawID();
-    UpdateID updateID = data->updateID();
-
-    QPolygonF polyMW;
     bool isVisible, isVisibleLast;
-    SkyPoint  *pLast, *pThis;
-    QPointF oThis, oThis2, oLast, oMid;
 
     MeshIterator region( skyMesh(), drawBuffer() );
     while ( region.hasNext() ) {
 
-        LineListList* lineListList = lineIndex()->value( region.next() );
-        if ( lineListList == 0 ) continue;
+        LineListList* lineListList = m_lineIndex->value( region.next() );
+        if ( lineListList == 0 )
+            continue;
 
         for (int i = 0; i < lineListList->size(); i++) {
             LineList* lineList = lineListList->at( i );
 
-            if ( lineList->drawID == drawID ) continue;
+            if ( lineList->drawID == drawID )
+                continue;
             lineList->drawID = drawID;
 
             if ( lineList->updateID != updateID )
-                JITupdate( data, lineList );
+                JITupdate( lineList );
 
             SkyList* points = lineList->points();
-            pLast = points->first();
-            oLast = map->toScreen( pLast, true, &isVisibleLast );
+            SkyPoint* pLast = points->first();
+            QPointF   oLast = map->toScreen( pLast, true, &isVisibleLast );
 
-            for ( int i = 1 ; i < points->size() ; i++ ) {
-                pThis = points->at( i );
+            QPointF oThis, oThis2;
+            for ( int j = 1 ; j < points->size() ; j++ ) {
+                SkyPoint* pThis = points->at( j );
                 oThis2 = oThis = map->toScreen( pThis, true, &isVisible );
 
-                if ( map->onScreen( oThis, oLast) && ! skipAt( lineList, i ) ) {
+                if ( map->onScreen( oThis, oLast) && ! skipAt( lineList, j ) ) {
 
-                    if ( isVisible && isVisibleLast ) {
-                        if ( map->onscreenLine2( oLast, oThis ) ) {
-                            psky.drawLine( oLast, oThis );
-                            updateLabelCandidates( oThis, lineList, i );
-                            //psky.drawEllipse( QRectF( oThis.x(), oThis.y(), 2, 2 ) );
-                        }
-                    }
-                    else if ( isVisibleLast ) {
-                        oMid = map->clipLine( pLast, pThis );
+                    if ( isVisible && isVisibleLast && map->onscreenLine( oLast, oThis ) ) {
+                        psky.drawLine( oLast, oThis );
+                        updateLabelCandidates( oThis, lineList, j );
+                    } else if ( isVisibleLast ) {
+                        QPointF oMid = map->clipLine( pLast, pThis );
                         psky.drawLine( oLast, oMid );
-                    }
-                    else if ( isVisible ) {
-                        oMid = map->clipLine( pThis, pLast );
+                    } else if ( isVisible ) {
+                        QPointF oMid = map->clipLine( pThis, pLast );
                         psky.drawLine( oMid, oThis );
                     }
                 }
@@ -303,25 +272,16 @@ void LineListIndex::drawLines( QPainter& psky )
 
 void LineListIndex::drawFilled( QPainter& psky )
 {
-    //bool antiAlias = psky.testRenderHint( QPainter::Antialiasing );
-    //if ( Options::zoomFactor() > 10.0 * MINZOOM )
-    //    psky.setRenderHint(QPainter::Antialiasing, false );
-
     SkyMap *map = SkyMap::Instance();
-    KStarsData *data = KStarsData::Instance();
+    DrawID drawID     = skyMesh()->drawID();
+    UpdateID updateID = KStarsData::Instance()->updateID();
 
-    DrawID drawID = skyMesh()->drawID();
-    UpdateID updateID = data->updateID();
-
-    QPolygonF polygon;
     bool isVisible, isVisibleLast;
-    SkyPoint  *pLast, *pThis;
-    QPointF oThis, oLast, oMid;
 
     MeshIterator region( skyMesh(), drawBuffer() );
     while ( region.hasNext() ) {
 
-        LineListList* lineListList =  polyIndex()->value( region.next() );
+        LineListList* lineListList =  m_polyIndex->value( region.next() );
         if ( lineListList == 0 ) continue;
 
         for (int i = 0; i < lineListList->size(); i++) {
@@ -332,25 +292,24 @@ void LineListIndex::drawFilled( QPainter& psky )
             lineList->drawID = drawID;
 
             if ( lineList->updateID != updateID )
-                JITupdate( data, lineList );
+                JITupdate( lineList );
 
             SkyList* points = lineList->points();
-            pLast = points->last();
-            oLast = map->toScreen( pLast, true, &isVisibleLast );
+            SkyPoint* pLast = points->last();
+            QPointF   oLast = map->toScreen( pLast, true, &isVisibleLast );
 
+            QPolygonF polygon;
             for ( int i = 0; i < points->size(); ++i ) {
-                pThis = points->at( i );
-                oThis = map->toScreen( pThis, true, &isVisible );
+                SkyPoint* pThis = points->at( i );
+                QPointF oThis = map->toScreen( pThis, true, &isVisible );
 
                 if ( isVisible && isVisibleLast ) {
                     polygon << oThis;
-                }
-                else if ( isVisibleLast ) {
-                    oMid = map->clipLine( pLast, pThis );
+                } else if ( isVisibleLast ) {
+                    QPointF oMid = map->clipLine( pLast, pThis );
                     polygon << oMid;
-                }
-                else if ( isVisible ) {
-                    oMid = map->clipLine( pThis, pLast );
+                } else if ( isVisible ) {
+                    QPointF oMid = map->clipLine( pThis, pLast );
                     polygon << oMid;
                     polygon << oThis;
                 }
@@ -360,8 +319,8 @@ void LineListIndex::drawFilled( QPainter& psky )
                 isVisibleLast = isVisible;
             }
 
-            if ( polygon.size() ) psky.drawPolygon( polygon );
-            polygon.clear();
+            if ( polygon.size() )
+                psky.drawPolygon( polygon );
         }
     }
     //psky.setRenderHint(QPainter::Antialiasing, antiAlias );
@@ -369,19 +328,20 @@ void LineListIndex::drawFilled( QPainter& psky )
 
 void LineListIndex::intro()
 {
-    emitProgressText( i18n( "Loading %1", name() ));
+    emitProgressText( i18n( "Loading %1", m_name ));
 
-    if ( skyMesh()->debug() < 1 ) return;
-    kDebug() << QString("Loading %1 ...").arg( name() );
+    if ( skyMesh()->debug() >= 1 )
+        kDebug() << QString("Loading %1 ...").arg( m_name );
 }
 
 void LineListIndex::summary()
 {
-    if ( skyMesh()->debug() < 2 ) return;
+    if ( skyMesh()->debug() < 2 )
+        return;
 
     int total = skyMesh()->size();
-    int polySize = polyIndex()->size();
-    int lineSize = lineIndex()->size();
+    int polySize = m_polyIndex->size();
+    int lineSize = m_lineIndex->size();
 
     if ( lineSize > 0 )
         printf("%4d out of %4d trixels in line index %3d%%\n",
