@@ -34,17 +34,18 @@
 #include "ksplanet.h"
 #include "kssun.h"
 #include "ksmoon.h"
+#include "skycomponents/skymapcomposite.h"
 
 QVector<QColor> KSPlanetBase::planetColor = QVector<QColor>() <<
   QColor("slateblue") << //Mercury
   QColor("lightgreen") << //Venus
-	QColor("red") << //Mars
-	QColor("goldenrod") << //Jupiter
-	QColor("khaki") << //Saturn
-	QColor("lightseagreen") << //Uranus
-	QColor("skyblue") << //Neptune
-	QColor("grey") << //Pluto
-	QColor("yellow") << //Sun
+  QColor("red") << //Mars
+  QColor("goldenrod") << //Jupiter
+  QColor("khaki") << //Saturn
+  QColor("lightseagreen") << //Uranus
+  QColor("skyblue") << //Neptune
+  QColor("grey") << //Pluto
+  QColor("yellow") << //Sun
   QColor("white"); //Moon
 
   
@@ -72,7 +73,6 @@ void KSPlanetBase::init( const QString &s, const QString &image_file, const QCol
         }
     }
     PositionAngle = 0.0;
-    ImageAngle = 0.0;
     PhysicalSize = pSize;
     m_Color = c;
     setName( s );
@@ -120,7 +120,7 @@ void KSPlanetBase::updateCoords( KSNumbers *num, bool includePlanets, const dms
         if ( lat && LST ) {
             findPosition( num, lat, LST, kd->skyComposite()->earth() );
             //Don't add to the trail this time
-            if ( hasTrail() )
+            if( hasTrail() )
                 Trail.takeLast();
         } else {
             findGeocentricPosition( num, kd->skyComposite()->earth() );
@@ -139,11 +139,11 @@ void KSPlanetBase::findPosition( const KSNumbers *num, const dms *lat, const dms
 
     if ( hasTrail() ) {
         addToTrail();
-        if ( Trail.size() > MAXTRAIL ) Trail.takeFirst();
+        if ( Trail.size() > MAXTRAIL )
+            clipTrail();
     }
 
-    if ( isMajorPlanet() || type() == SkyObject::ASTEROID || type() == SkyObject::COMET || type() == SkyObject::MOON )
-        findMagnitude(num);
+    findMagnitude(num);
 
     if ( type() == SkyObject::COMET ) {
         // Compute tail size
@@ -174,16 +174,16 @@ void KSPlanetBase::localizeCoords( const KSNumbers *num, const dms *lat, const d
     u = atan( 0.996647*tan( lat->radians() ) );
     rsinp = 0.996647*sin( u );
     rcosp = cos( u );
-    HA.setD( LST->Degrees() - ra()->Degrees() );
+    HA.setD( LST->Degrees() - ra().Degrees() );
     HA.SinCos( sinHA, cosHA );
-    dec()->SinCos( sinDec, cosDec );
+    dec().SinCos( sinDec, cosDec );
 
     D = atan2( rcosp*sinHA, r*cosDec/6378.14 - rcosp*cosHA );
     dms temp;
-    temp.setRadians( ra()->radians() - D );
+    temp.setRadians( ra().radians() - D );
     setRA( temp );
 
-    HA2.setD( LST->Degrees() - ra()->Degrees() );
+    HA2.setD( LST->Degrees() - ra().Degrees() );
     cosHA2 = cos( HA2.radians() );
 
     //temp.setRadians( atan2( cosHA2*( r*sinDec/6378.14 - rsinp ), r*cosDec*cosHA/6378.14 - rcosp ) );
@@ -193,15 +193,15 @@ void KSPlanetBase::localizeCoords( const KSNumbers *num, const dms *lat, const d
     setDec( temp );
 
     //Make sure Dec is between -90 and +90
-    if ( dec()->Degrees() > 90.0 ) {
-        setDec( 180.0 - dec()->Degrees() );
-        setRA( ra()->Hours() + 12.0 );
-        ra()->reduce();
+    if ( dec().Degrees() > 90.0 ) {
+        setDec( 180.0 - dec().Degrees() );
+        setRA( ra().Hours() + 12.0 );
+        ra().reduce();
     }
-    if ( dec()->Degrees() < -90.0 ) {
-        setDec( 180.0 + dec()->Degrees() );
-        setRA( ra()->Hours() + 12.0 );
-        ra()->reduce();
+    if ( dec().Degrees() < -90.0 ) {
+        setDec( 180.0 + dec().Degrees() );
+        setRA( ra().Hours() + 12.0 );
+        ra().reduce();
     }
 
     EquatorialToEcliptic( num->obliquity() );
@@ -253,17 +253,15 @@ void KSPlanetBase::findPA( const KSNumbers *num ) {
     SkyPoint test;
     dms newELat( ecLat()->Degrees() + 1.0 );
     test.setFromEcliptic( num->obliquity(), ecLong(), &newELat );
-    double dx = ra()->Degrees() - test.ra()->Degrees(); 
-    double dy = test.dec()->Degrees() - dec()->Degrees();
+    double dx = ra().Degrees() - test.ra().Degrees(); 
+    double dy = test.dec().Degrees() - dec().Degrees();
     double pa;
     if ( dy ) {
         pa = atan2( dx, dy )*180.0/dms::PI;
     } else {
-		    pa = 90.0;
-		    if ( dx > 0 ) pa = -90.0;
+        pa = dx < 0 ? 90.0 : -90.0;
     }
     setPA( pa );
-
 }
 
 double KSPlanetBase::labelOffset() const {
@@ -286,18 +284,12 @@ double KSPlanetBase::labelOffset() const {
     return 0.5*size + 4.;
 }
 
-void KSPlanetBase::rotateImage( double imAngle ) {
-    ImageAngle = imAngle;
-    QMatrix m;
-    m.rotate( ImageAngle );
-    Image = Image0.transformed( m );
-}
-
 void KSPlanetBase::scaleRotateImage( float size, double imAngle ) {
-    ImageAngle = imAngle;
     QMatrix m;
-    m.rotate( ImageAngle );
-    Image = Image0.transformed( m ).scaledToWidth( int(size) );
+    m.rotate( imAngle );
+    double scale = size / Image0.width();
+    m.scale( scale, scale );
+    Image = Image0.transformed( m );
 }
 
 void KSPlanetBase::findPhase() {
