@@ -1,8 +1,8 @@
 /***************************************************************************
-                          kwordquiz.h  -  description
+                                 kwordquiz.h
                              -------------------
     begin                : Wed Jul 24 20:12:30 PDT 2002
-    copyright            : (C) 2002-2008 by Peter Hedlund
+    copyright            : (C) 2002-2010 by Peter Hedlund
     email                : peter.hedlund@kdemail.net
  ***************************************************************************/
 
@@ -159,6 +159,8 @@ class KWordQuizApp : public KXmlGuiWindow
     void slotFileClose();
     /** print the actual file */
     void slotFilePrint();
+    /** preview the appearance of the vocabulary as printed */
+    void slotFilePrintPreview();
     /** closes all open windows by calling close() on each memberList item until the list is empty, then quits the application.
      * If queryClose() returns false because the user canceled the saveModified() dialog, the closing breaks.*/
     void slotFileQuit();
@@ -184,6 +186,10 @@ class KWordQuizApp : public KXmlGuiWindow
     void slotVocabLanguages();
     /** define vocabulary fonts */
     void slotVocabFont();
+    /** link an image to the current entry */
+    void slotVocabImage();
+    /** link a sound to the current entry */
+    void slotVocabSound();
     /** automatically adjust row heights */
     void slotVocabAdjustRows();
     /** shuffle the vocabulary */
@@ -224,10 +230,10 @@ class KWordQuizApp : public KXmlGuiWindow
     void slotCleanChanged(bool);
     void slotUndoTextChanged(const QString &);
     void slotRedoTextChanged(const QString &);
-    
+
     void slotTableContextMenuRequested(const QPoint &);
     void slotLayoutActionGroupTriggered(QAction *);
-    
+
   private:
     KWQQuizModel *m_quiz;
 
@@ -268,6 +274,7 @@ class KWordQuizApp : public KXmlGuiWindow
     QAction* fileSaveAs;
     QAction* fileClose;
     QAction* filePrint;
+    QAction* filePrintPreview;
     QAction* fileQuit;
 
     QAction* editUndo;
@@ -305,6 +312,7 @@ class KWordQuizApp : public KXmlGuiWindow
     KAction* flashDontKnow;
 
     KAction* qaHint;
+    KAction* qaMarkLastCorrect;
 
     KAction* quizOpt1;
     KAction* quizOpt2;
@@ -316,8 +324,6 @@ class KWordQuizApp : public KXmlGuiWindow
 
     KDirWatch * m_dirWatch;
 
-    QLabel * m_modeLabel;
-
     KUndoStack * m_undoStack;
 
     void updateActions();
