@@ -5,21 +5,21 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 #include "MarbleTest.h"
 
 #include <QtCore/QCoreApplication>
-#include <QtCore/QDebug>
 #include <QtCore/QTime>
 #include <QtGui/QMessageBox>
 #include <QtGui/QFileDialog>
 
-#include <lib/global.h>
-#include <lib/MarbleWidget.h>
-#include <lib/MarbleModel.h>
+#include <global.h>
+#include <MarbleDebug.h>
+#include <MarbleWidget.h>
+#include <MarbleModel.h>
 
 using namespace Marble;
 
@@ -32,7 +32,7 @@ void MarbleTest::timeDemo()
 {
     m_marbleWidget->zoomView( 1500 );
     m_marbleWidget->setMapThemeId( "earth/srtm/srtm.dgml" );
-    m_marbleWidget->setMapQuality( Marble::Normal );
+    m_marbleWidget->setMapQuality( Marble::NormalQuality );
 //    m_marbleWidget->resize( 800, 600 );
     m_marbleWidget->centerOn( 9.4, 54.8 );
 
