@@ -16,6 +16,7 @@
 #include "AbstractDataPluginItem.h"
 #include "GeoPainter.h"
 #include "GeoSceneLayer.h"
+#include "MarbleDataFacade.h"
 #include "ViewportParams.h"
 #include "MarbleDebug.h"
 
@@ -68,7 +69,7 @@ QString AbstractDataPlugin::renderPolicy() const
 
 QStringList AbstractDataPlugin::renderPosition() const
 {
-    return QStringList( "HOVERS_ABOVE_SURFACE" );
+    return QStringList( "ALWAYS_ON_TOP" );
 }
 
 bool AbstractDataPlugin::isInitialized() const
@@ -83,7 +84,7 @@ bool AbstractDataPlugin::render( GeoPainter *painter, ViewportParams *viewport,
         return true;
     }
     
-    if ( renderPos != "HOVERS_ABOVE_SURFACE" ) {
+    if ( renderPos != "ALWAYS_ON_TOP" ) {
         return true;
     }
 
@@ -118,6 +119,11 @@ void AbstractDataPlugin::setModel( AbstractDataPluginModel* model )
     connect( d->m_model, SIGNAL( itemsUpdated() ), this, SLOT( requestRepaint() ) );
 }
 
+PluginManager* AbstractDataPlugin::pluginManager() const
+{
+    return dataFacade()->pluginManager();
+}
+
 QString AbstractDataPlugin::nameId() const
 {
     return d->m_name;
@@ -145,7 +151,7 @@ void AbstractDataPlugin::setNumberOfItems( quint32 number )
 
 QList<AbstractDataPluginItem *> AbstractDataPlugin::whichItemAt( const QPoint& curpos )
 {
-    if ( enabled() && visible() ) {
+    if ( d->m_model && enabled() && visible()) {
         return d->m_model->whichItemAt( curpos );
     }
     else {
