@@ -8,8 +8,8 @@
 // Copyright 2009      Bastian Holst <bastianholst@gmx.de>
 //
 
-#ifndef ABSTRACTDATAPLUGINMODEL_H
-#define ABSTRACTDATAPLUGINMODEL_H
+#ifndef MARBLE_ABSTRACTDATAPLUGINMODEL_H
+#define MARBLE_ABSTRACTDATAPLUGINMODEL_H
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
@@ -28,6 +28,7 @@ class AbstractDataPluginModelPrivate;
 class AbstractDataPluginItem;
 class GeoDataLatLonAltBox;
 class MarbleDataFacade;
+class PluginManager;
 class ViewportParams;
 
 /**
@@ -45,7 +46,9 @@ class MARBLE_EXPORT AbstractDataPluginModel : public QObject
     Q_OBJECT
  
  public:
-    explicit AbstractDataPluginModel( const QString& name, QObject *parent = 0 );
+    explicit AbstractDataPluginModel( const QString& name,
+                                      PluginManager *pluginManager,
+                                      QObject *parent = 0 );
     virtual ~AbstractDataPluginModel();
         
     /**
@@ -178,4 +181,4 @@ class MARBLE_EXPORT AbstractDataPluginModel : public QObject
 
 }
 
-#endif // ABSTRACTDATAPLUGINMODEL_H
+#endif
