@@ -5,35 +5,31 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>"
+// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>
 //
 
 //
 // Description: AbstractTile contains the base class for a single quadtile 
 //
 
-
 #ifndef MARBLE_ABSTRACTTILE_P_H
 #define MARBLE_ABSTRACTTILE_P_H
 
 #include "TileId.h"
 
-
 namespace Marble
 {
 
-
-class AbstractTilePrivate {
+class AbstractTilePrivate
+{
  public:
-    AbstractTilePrivate( const TileId& id );
+    explicit AbstractTilePrivate( const TileId& id );
     virtual ~AbstractTilePrivate();
 
     TileId    m_id;
     bool      m_used;
     AbstractTile::TileState m_state;
 
-    QDateTime m_created;
-
     AbstractTile * q_ptr;
 };
 
