@@ -8,8 +8,8 @@
 // Copyright 2009      Bastian Holst <bastianholst@gmx.de>
 //
 
-#ifndef FILESTORAGEWATCHER_H
-#define FILESTORAGEWATCHER_H
+#ifndef MARBLE_FILESTORAGEWATCHER_H
+#define MARBLE_FILESTORAGEWATCHER_H
 
 #include <QtCore/QThread>
 #include <QtCore/QMutex>
@@ -59,7 +59,7 @@ class FileStorageWatcherThread : public QObject
 	 *
 	 * @param mapTheme The identifier of the new theme.
 	 */
-	void updateTheme( QString mapTheme );
+	void updateTheme( const QString &mapTheme );
 	
 	/**
 	 * Stop doing things that take a long time to quit.
@@ -83,12 +83,12 @@ class FileStorageWatcherThread : public QObject
 	/**
 	 * Deletes files of a planet if needed
 	 */
-	void ensureSizePerPlanet( QString planetDirectory, QString currentTheme = QString() );
+	void ensureSizePerPlanet( const QString &planetDirectory, const QString &currentTheme = QString() );
 	
 	/**
 	 * Deletes files of a theme if needed
 	 */
-	void ensureSizePerTheme( QString themeDirectory );
+	void ensureSizePerTheme( const QString &themeDirectory );
 	
 	/**
 	 * Returns true if it is necessary to delete files.
@@ -100,7 +100,7 @@ class FileStorageWatcherThread : public QObject
         quint64 m_cacheLimit;
 	quint64 m_cacheSoftLimit;
         quint64 m_currentCacheSize;
-	quint8  m_filesDeleted;
+	int     m_filesDeleted;
 	bool 	m_deleting;
 	QString m_mapThemeId;
 	QMutex	m_limitMutex;
@@ -154,7 +154,7 @@ class FileStorageWatcher : public QThread
 	 *
 	 * @param mapTheme The identifier of the new theme.
 	 */
-	void updateTheme( QString mapTheme );
+	void updateTheme( const QString &mapTheme );
 	
     Q_SIGNALS:
 	void sizeChanged( qint64 bytes );
@@ -181,4 +181,4 @@ class FileStorageWatcher : public QThread
 
 }
 
-#endif // FILESTORAGEWATCHER_H
+#endif
