@@ -9,22 +9,21 @@
 // Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
-
-#ifndef FILEVIEWMODEL_H
-#define FILEVIEWMODEL_H
+#ifndef MARBLE_FILEVIEWMODEL_H
+#define MARBLE_FILEVIEWMODEL_H
 
 #include <QtCore/QAbstractListModel>
 #include <QtCore/QVariant>
-#include <QtGui/QItemSelectionModel>
 
 #include "marble_export.h"
 
-#include "FileManager.h"
+class QItemSelectionModel;
 
 namespace Marble
 {
 
 class AbstractFileViewItem;
+class FileManager;
 
 class MARBLE_EXPORT FileViewModel : public QAbstractListModel
 {
