@@ -5,18 +5,22 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 
 #include "MarbleDirs.h"
+#include "MarbleDebug.h"
 
-#include <QtCore/QDebug>
 #include <QtCore/QDir>
 #include <QtCore/QFile>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 #include <QtGui/QApplication>
 
+#include <stdlib.h>
+
 #ifdef Q_OS_MACX
 //for getting app bundle path
 #include <ApplicationServices/ApplicationServices.h>
@@ -24,7 +28,8 @@
 
 #ifdef Q_OS_WIN
 //for getting appdata path
-#define _WIN32_IE 0x0400
+//mingw-w64 Internet Explorer 5.01
+#define _WIN32_IE 0x0501
 #include <shlobj.h>
 #endif
 
@@ -213,7 +218,11 @@ if ( !runTimeMarblePluginPath.isEmpty() )
 QString MarbleDirs::localPath() 
 {
 #ifndef Q_OS_WIN
-    return QString( QDir::homePath() + "/.marble/data" ); // local path
+    QString dataHome = getenv( "XDG_DATA_HOME" );
+    if( dataHome.isEmpty() )
+        dataHome = QDir::homePath() + "/.local/share";
+
+    return dataHome + "/marble"; // local path
 #else
     HWND hwnd = 0;
     WCHAR *appdata_path = new WCHAR[MAX_PATH+1];
@@ -225,6 +234,39 @@ QString MarbleDirs::localPath()
 #endif
 }
 
+QStringList MarbleDirs::oldLocalPaths()
+{
+    QStringList possibleOldPaths;
+
+#ifndef Q_OS_WIN
+    QString oldDefault = QDir::homePath() + "/.marble/data";
+    possibleOldPaths.append( oldDefault );
+
+    QString xdgDefault = QDir::homePath() + "/.local/share/marble";
+    possibleOldPaths.append( xdgDefault );
+
+    QString xdg = getenv( "XDG_DATA_HOME" );
+    xdg += "/marble/";
+    possibleOldPaths.append( xdg );
+#endif
+    QString currentLocalPath = QDir( MarbleDirs::localPath() ).canonicalPath();
+    QStringList oldPaths;
+    foreach( const QString& possibleOldPath, possibleOldPaths ) {
+        if( !QDir().exists( possibleOldPath ) ) {
+            continue;
+        }
+
+        QString canonicalPossibleOldPath = QDir( possibleOldPath ).canonicalPath();
+        if( canonicalPossibleOldPath == currentLocalPath ) {
+            continue;
+        }
+
+        oldPaths.append( canonicalPossibleOldPath );
+    }
+
+    return oldPaths;
+}
+
 QString MarbleDirs::pluginLocalPath() 
 {
 #ifndef Q_OS_WIN
@@ -277,17 +319,17 @@ void MarbleDirs::setMarblePluginPath( const QString& adaptedPath )
 
 void MarbleDirs::debug()
 {
-    qDebug() << "=== MarbleDirs: ===";
-    qDebug() << "Local Path:" << localPath();
-    qDebug() << "Plugin Local Path:" << pluginLocalPath();
-    qDebug() << "";
-    qDebug() << "Marble Data Path (Run Time) :" << runTimeMarbleDataPath; 
-    qDebug() << "Marble Data Path (Compile Time):" << QString(MARBLE_DATA_PATH); 
-    qDebug() << "";
-    qDebug() << "Marble Plugin Path (Run Time) :" << runTimeMarblePluginPath; 
-    qDebug() << "Marble Plugin Path (Compile Time):" << QString(MARBLE_PLUGIN_PATH); 
-    qDebug() << "";
-    qDebug() << "System Path:" << systemPath();
-    qDebug() << "Plugin System Path:" << pluginSystemPath();
-    qDebug() << "===================";
+    mDebug() << "=== MarbleDirs: ===";
+    mDebug() << "Local Path:" << localPath();
+    mDebug() << "Plugin Local Path:" << pluginLocalPath();
+    mDebug() << "";
+    mDebug() << "Marble Data Path (Run Time) :" << runTimeMarbleDataPath; 
+    mDebug() << "Marble Data Path (Compile Time):" << QString(MARBLE_DATA_PATH); 
+    mDebug() << "";
+    mDebug() << "Marble Plugin Path (Run Time) :" << runTimeMarblePluginPath; 
+    mDebug() << "Marble Plugin Path (Compile Time):" << QString(MARBLE_PLUGIN_PATH); 
+    mDebug() << "";
+    mDebug() << "System Path:" << systemPath();
+    mDebug() << "Plugin System Path:" << pluginSystemPath();
+    mDebug() << "===================";
 }
