@@ -5,14 +5,13 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007-2008 Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007-2008 Inge Wallin  <ingwa@kde.org>
 //
 
 #include "PlacemarkLayout.h"
 
 #include <QtCore/QAbstractItemModel>
-#include <QtCore/QDebug>
 #include <QtCore/QList>
 #include <QtCore/QPoint>
 #include <QtCore/QVector>
@@ -26,6 +25,7 @@
 #include "GeoDataPlacemark.h"
 #include "GeoDataStyle.h"
 
+#include "MarbleDebug.h"
 #include "global.h"
 #include "PlacemarkPainter.h"
 #include "MarblePlacemarkModel.h"
@@ -110,7 +110,7 @@ PlacemarkLayout::~PlacemarkLayout()
 
 void PlacemarkLayout::requestStyleReset()
 {
-    qDebug() << "Style reset requested.";
+    mDebug() << "Style reset requested.";
     m_styleResetRequested = true;
 }
 
@@ -153,7 +153,7 @@ PlacemarkPainter* PlacemarkLayout::placemarkPainter() const
 int PlacemarkLayout::maxLabelHeight( const QAbstractItemModel* model,
                                      const QItemSelectionModel* selectionModel ) const
 {
-    qDebug() << "Detecting maxLabelHeight ...";
+    mDebug() << "Detecting maxLabelHeight ...";
 
     int maxLabelHeight = 0;
 
@@ -178,7 +178,7 @@ int PlacemarkLayout::maxLabelHeight( const QAbstractItemModel* model,
             maxLabelHeight = textHeight; 
     }
 
-    //qDebug() <<"Detected maxLabelHeight: " << maxLabelHeight;
+    //mDebug() <<"Detected maxLabelHeight: " << maxLabelHeight;
     return maxLabelHeight;
 }
 
@@ -251,6 +251,12 @@ void PlacemarkLayout::paintPlaceFolder( QPainter   *painter,
     for ( int i = 0; i < selectedIndexes.count(); ++i ) {
         const QModelIndex index = selectedIndexes.at( i );
 
+        GeoDataGeometry geometry
+                = qvariant_cast<GeoDataGeometry>( index.data( MarblePlacemarkModel::GeometryRole ) );
+        if( geometry.geometryId() != GeoDataPointId ) {
+            continue;
+        }
+
         GeoDataCoordinates geopoint = qvariant_cast<GeoDataCoordinates>( index.data( MarblePlacemarkModel::CoordinateRole ) );
 
         if ( !latLonAltBox.contains( geopoint ) ||
@@ -342,7 +348,13 @@ void PlacemarkLayout::paintPlaceFolder( QPainter   *painter,
     {
         const QModelIndex& index = model->index( i, 0 );
         if( !index.isValid() ) {
-            qDebug() << "invalid index!!!";
+            mDebug() << "invalid index!!!";
+            continue;
+        }
+
+        GeoDataGeometry geometry
+                = qvariant_cast<GeoDataGeometry>( index.data( MarblePlacemarkModel::GeometryRole ) );
+        if( geometry.geometryId() != GeoDataPointId ) {
             continue;
         }
 
@@ -495,7 +507,7 @@ QRect PlacemarkLayout::roomForLabel( GeoDataStyle * style,
 
     QFont labelFont = style->labelStyle().font();
     int textHeight = QFontMetrics( labelFont ).height();
-//    qDebug() << textHeight;
+//    mDebug() << textHeight;
 
     if ( style->labelStyle().alignment() == GeoDataLabelStyle::Corner ) {
         int  xpos = symbolwidth / 2 + x + 1;
