@@ -5,12 +5,12 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2007      Tobias Koenig <tokoe@kde.org>"
+// Copyright 2007      Tobias Koenig <tokoe@kde.org>
 // Copyright 2009      Bastian Holst <bastianholst@gmx.de
 //
 
-#ifndef STORAGEPOLICY_H
-#define STORAGEPOLICY_H
+#ifndef MARBLE_STORAGEPOLICY_H
+#define MARBLE_STORAGEPOLICY_H
 
 
 #include <QtCore/QObject>
