@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2005-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2005-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 
@@ -17,11 +17,11 @@
 // Author: Torsten Rahn
 //
 
-
-#ifndef VECTORCOMPOSER_H
-#define VECTORCOMPOSER_H
+#ifndef MARBLE_VECTORCOMPOSER_H
+#define MARBLE_VECTORCOMPOSER_H
 
 
+#include <QtCore/QObject>
 #include <QtCore/QVector>
 #include <QtGui/QBrush>
 #include <QtGui/QPen>
@@ -37,18 +37,18 @@ class VectorMap;
 class ViewParams;
 
 
-class VectorComposer
+class VectorComposer : public QObject
 {
-
+    Q_OBJECT
  public:
-    VectorComposer();
+    VectorComposer( QObject * parent = 0 );
     virtual ~VectorComposer();
 
     // This method contains all the polygons that define the coast lines.
     void loadCoastlines();
 
     // This method contains all the other polygons
-    void loadOverlay();
+    void loadOverlays();
 
     void  drawTextureMap( ViewParams *viewParams );
     void  paintBaseVectorMap( GeoPainter*, ViewParams* );
@@ -117,6 +117,9 @@ class VectorComposer
         m_statePen.setStyle( Qt::DotLine );
     }
 
+ Q_SIGNALS:
+    void datasetLoaded();
+
  private:
     Q_DISABLE_COPY( VectorComposer )
     VectorMap  *m_vectorMap;
@@ -162,8 +165,11 @@ class VectorComposer
     QBrush      m_dateLineBrush;
 
     QVector<qreal> m_dashes;
+
+    bool        m_coastLinesLoaded;
+    bool        m_overlaysLoaded;
 };
 
 }
 
-#endif // VECTORCOMPOSER_H
+#endif
