@@ -5,13 +5,12 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 // Copyright 2008      Jens-Michael Hoffmann <jensmh@gmx.de>
 //
 
-
-#ifndef VIEWPARAMS_H
-#define VIEWPARAMS_H
+#ifndef MARBLE_VIEWPARAMS_H
+#define MARBLE_VIEWPARAMS_H
 
 
 /** @file
@@ -59,8 +58,8 @@ class MARBLE_EXPORT ViewParams
  *  passed on to the MarbleModel and the MarbleLegendBrowser. 
  */
     void setMapThemeId( const QString& );
-    QString mapThemeId();
-    Marble::GeoSceneDocument *mapTheme();
+    //QString mapThemeId() const;
+    GeoSceneDocument *mapTheme();
 
     // Convenience methods:
 
@@ -68,8 +67,8 @@ class MARBLE_EXPORT ViewParams
     AbstractProjection *currentProjection() const;
     void setProjection(Projection newProjection);
 
-    Marble::MapQuality mapQuality();
-    void setMapQuality( Marble::MapQuality );
+    MapQuality mapQuality() const;
+    void setMapQuality( MapQuality );
 
     /**
      * @brief  Set the value of a map theme property
@@ -118,6 +117,9 @@ class MARBLE_EXPORT ViewParams
     bool showAtmosphere() const;
     void setShowAtmosphere( bool );
 
+    bool showClouds() const;
+    void setShowClouds( bool const );
+
     // FIXME: We should try to get rid of these
     int radiusUpdated() const;
     void setRadiusUpdated( const int );
@@ -131,4 +133,4 @@ class MARBLE_EXPORT ViewParams
 
 }
 
-#endif // VIEWPARAMS_H
+#endif
