@@ -8,15 +8,17 @@
 // Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
-#ifndef GEODATALINESTRINGPRIVATE_H
-#define GEODATALINESTRINGPRIVATE_H
+#ifndef MARBLE_GEODATALINESTRINGPRIVATE_H
+#define MARBLE_GEODATALINESTRINGPRIVATE_H
 
 #include "GeoDataGeometry_p.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
-class GeoDataLineStringPrivate : public Marble::GeoDataGeometryPrivate
+class GeoDataLineStringPrivate : public GeoDataGeometryPrivate
 {
   public:
     GeoDataLineStringPrivate( TessellationFlags f )
@@ -83,4 +85,4 @@ class GeoDataLineStringPrivate : public Marble::GeoDataGeometryPrivate
 
 } // namespace Marble
 
-#endif //GEODATALINESTRINGPRIVATE_H
+#endif
