@@ -13,7 +13,7 @@
 #include "GeoDataPolygon.h"
 #include "GeoDataPolygon_p.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 
 namespace Marble
@@ -32,7 +32,7 @@ GeoDataPolygon::GeoDataPolygon( const GeoDataGeometry & other )
 GeoDataPolygon::~GeoDataPolygon()
 {
 #ifdef DEBUG_GEODATA
-    qDebug() << "delete polygon";
+    mDebug() << "delete polygon";
 #endif
 }
 
@@ -41,6 +41,11 @@ GeoDataPolygonPrivate* GeoDataPolygon::p() const
     return static_cast<GeoDataPolygonPrivate*>(d);
 }
 
+QString GeoDataPolygon::nodeType() const
+{
+    return p()->nodeType();
+}
+
 bool GeoDataPolygon::isClosed() const
 {
     return true;
@@ -79,12 +84,7 @@ void GeoDataPolygon::setTessellationFlags( TessellationFlags f )
 
 GeoDataLatLonAltBox GeoDataPolygon::latLonAltBox() const
 {
-    if (p()->m_dirtyBox) {
-        // calculate LatLonAltBox
-    }
-    p()->m_dirtyBox = false;
-
-    return GeoDataLatLonAltBox();
+    return p()->outer.latLonAltBox();
 }
 
 GeoDataLinearRing& GeoDataPolygon::outerBoundary() const
@@ -122,7 +122,7 @@ void GeoDataPolygon::pack( QDataStream& stream ) const
           = p()->inner.constBegin(); 
          iterator != p()->inner.constEnd();
          ++iterator ) {
-        qDebug() << "innerRing: size" << p()->inner.size();
+        mDebug() << "innerRing: size" << p()->inner.size();
         GeoDataLinearRing linearRing = ( *iterator );
         linearRing.pack( stream );
     }
