@@ -31,6 +31,7 @@ namespace dgml
 const char* dgmlTag_nameSpace20 = "http://edu.kde.org/marble/dgml/2.0";
 
 const char* dgmlTag_Available = "available";
+const char* dgmlTag_Blending = "blending";
 const char* dgmlTag_Brush = "brush";
 const char* dgmlTag_Coastline = "coastline";
 const char* dgmlTag_Color = "color";
@@ -40,6 +41,7 @@ const char* dgmlTag_Description = "description";
 const char* dgmlTag_Dgml = "dgml";
 const char* dgmlTag_Discrete = "discrete";
 const char* dgmlTag_Document = "document";
+const char* dgmlTag_DownloadPolicy = "downloadPolicy";
 const char* dgmlTag_DownloadUrl = "downloadUrl";
 const char* dgmlTag_Filter = "filter";
 const char* dgmlTag_Geodata = "geodata";
