@@ -23,8 +23,8 @@
 // Own
 #include "GeoDataParser.h"
 
-// Qt
-#include <QtCore/QDebug>
+// Marble
+#include "MarbleDebug.h"
 
 // Geodata
 #include "GeoDataDocument.h"
@@ -53,21 +53,44 @@ GeoDataParser::~GeoDataParser()
 {
 }
 
-bool GeoDataParser::isValidDocumentElement() const
+bool GeoDataParser::isValidRootElement()
 {
+    if (m_source == GeoData_UNKNOWN)
+    {
+        if (GeoParser::isValidElement(gpx::gpxTag_gpx))
+        {
+            m_source = GeoData_GPX;
+        }
+        else if (GeoParser::isValidElement(kml::kmlTag_kml))
+        {
+            m_source = GeoData_KML;
+        }
+        else if (GeoParser::isValidElement("osm"))
+        {
+            m_source = GeoData_OSM;
+        }
+        else
+        {
+            Q_ASSERT(false);
+            return false;
+        }
+    }
     switch ((GeoDataSourceType) m_source) {
     // TODO: case GeoData_GeoRSS:
     case GeoData_GPX:
         return isValidElement(gpx::gpxTag_gpx);
     case GeoData_KML:
         return isValidElement(kml::kmlTag_kml);
+    case GeoData_OSM:
+        //does not have a namespace
+        return isValidElement("osm");
     default:
         Q_ASSERT(false);
         return false;
     }
 }
 
-void GeoDataParser::raiseDocumentElementError()
+void GeoDataParser::raiseRootElementError()
 {
     switch ((GeoDataSourceType) m_source) {
     // TODO: case GeoData_GeoRSS:
@@ -78,7 +101,7 @@ void GeoDataParser::raiseDocumentElementError()
         raiseError(QObject::tr("The file is not a valid KML 2.0 / 2.1 / 2.2 file"));
         break;
     default:
-        GeoParser::raiseDocumentElementError();
+        GeoParser::raiseRootElementError();
         break;
     }
 }
@@ -95,7 +118,11 @@ bool GeoDataParser::isValidElement(const QString& tagName) const
     case GeoData_KML:
         return (namespaceUri() == kml::kmlTag_nameSpace20 || 
                 namespaceUri() == kml::kmlTag_nameSpace21 || 
-                namespaceUri() == kml::kmlTag_nameSpace22);
+                namespaceUri() == kml::kmlTag_nameSpace22 ||
+                namespaceUri() == kml::kmlTag_nameSpaceOgc22);
+    case GeoData_OSM:
+        //always "valid" because there is no namespace
+        return true;
     default:
         break;
     }
