@@ -22,6 +22,7 @@
 #include "GeoSceneLayer.h"
 
 #include <limits>
+#include "GeoSceneFilter.h"
 
 namespace Marble
 {
@@ -30,7 +31,7 @@ namespace Marble
 
 GeoSceneAbstractDataset::GeoSceneAbstractDataset( const QString& name )
     : m_name( name ),
-      m_fileFormat( "" ),
+      m_fileFormat(),
       m_expire( std::numeric_limits<int>::max() )
 {
 }
@@ -63,11 +64,10 @@ void GeoSceneAbstractDataset::setExpire( int expire )
 GeoSceneLayer::GeoSceneLayer( const QString& name )
     : m_filter( 0 ),
       m_name( name ),
-      m_backend( "" ),
-      m_role( "" ),
+      m_backend(),
+      m_role(),
       m_tiled( true )
 {
-    /* NOOP */
 }
 
 GeoSceneLayer::~GeoSceneLayer()
@@ -84,6 +84,7 @@ void GeoSceneLayer::addDataset( GeoSceneAbstractDataset* dataset )
         if ( currentAbstractDataset->name() == dataset->name() ) {
             delete currentAbstractDataset;
             it = m_datasets.erase(it);
+            break;
         }
         else {
             ++it;
@@ -95,28 +96,30 @@ void GeoSceneLayer::addDataset( GeoSceneAbstractDataset* dataset )
     }
 }
 
-GeoSceneAbstractDataset* GeoSceneLayer::dataset( const QString& name )
+const GeoSceneAbstractDataset* GeoSceneLayer::dataset( const QString& name ) const
 {
     GeoSceneAbstractDataset* dataset = 0;
 
     QVector<GeoSceneAbstractDataset*>::const_iterator it = m_datasets.constBegin();
-    for (; it != m_datasets.constEnd(); ++it) {
-        if ( (*it)->name() == name )
+    QVector<GeoSceneAbstractDataset*>::const_iterator end = m_datasets.constEnd();
+    for (; it != end; ++it) {
+        if ( (*it)->name() == name ) {
             dataset = *it;
+            break;
+        }
     }
-
-    if ( dataset ) {
-        Q_ASSERT(dataset->name() == name);
-        return dataset;
-    }
-
-//    dataset = new GeoSceneAbstractDataset( name );
-//    addDataset( dataset );
-
     return dataset;
 }
 
-GeoSceneAbstractDataset * GeoSceneLayer::groundDataset() const
+// implement non-const method by means of const method,
+// for details, see "Effective C++" (third edition)
+GeoSceneAbstractDataset* GeoSceneLayer::dataset( const QString& name )
+{
+    return const_cast<GeoSceneAbstractDataset*>
+        ( static_cast<GeoSceneLayer const *>( this )->dataset( name ));
+}
+
+const GeoSceneAbstractDataset * GeoSceneLayer::groundDataset() const
 {
     if ( m_datasets.isEmpty() )
         return 0;
@@ -124,6 +127,14 @@ GeoSceneAbstractDataset * GeoSceneLayer::groundDataset() const
     return m_datasets.first();
 }
 
+// implement non-const method by means of const method,
+// for details, see "Effective C++" (third edition)
+GeoSceneAbstractDataset * GeoSceneLayer::groundDataset()
+{
+    return const_cast<GeoSceneAbstractDataset*>
+        ( static_cast<GeoSceneLayer const *>( this )->groundDataset() );
+}
+
 QVector<GeoSceneAbstractDataset *> GeoSceneLayer::datasets() const
 {
     return m_datasets;
@@ -164,6 +175,11 @@ void GeoSceneLayer::setRole( const QString& role )
     m_role = role;
 }
 
+const GeoSceneFilter* GeoSceneLayer::filter() const
+{
+    return m_filter;
+}
+
 GeoSceneFilter* GeoSceneLayer::filter()
 {
     return m_filter;
@@ -176,7 +192,9 @@ void GeoSceneLayer::addFilter( GeoSceneFilter * filter )
 
 void GeoSceneLayer::removeFilter( GeoSceneFilter * filter )
 {
-    if( filter == m_filter ) { m_filter = 0; }
+    if ( filter == m_filter ) {
+        m_filter = 0;
+    }
 }
 
 }
