@@ -19,8 +19,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef GEOSCENESETTINGS_H
-#define GEOSCENESETTINGS_H
+#ifndef MARBLE_GEOSCENESETTINGS_H
+#define MARBLE_GEOSCENESETTINGS_H
 
 #include <QtCore/QObject>
 #include <QtCore/QString>
@@ -57,7 +57,7 @@ class GEODATA_EXPORT GeoSceneSettings : public QObject,
      * @return @c true  the property was registered across groups
      *         @c false the property wasn't registered across groups
      */
-    bool propertyAvailable( const QString& name, bool& available  );
+    bool propertyAvailable( const QString& name, bool& available ) const;
 
     /**
      * @brief  Set the value of a property across groups
@@ -75,7 +75,7 @@ class GEODATA_EXPORT GeoSceneSettings : public QObject,
      * @return @c true  the property was found and returned accordingly
      *         @c false the property couldn't be found in this group
      */
-    bool propertyValue( const QString& name, bool& value  );
+    bool propertyValue( const QString& name, bool& value ) const;
 
     /**
      * @brief  Get the whole list of properties stored in the settings
@@ -92,6 +92,7 @@ class GEODATA_EXPORT GeoSceneSettings : public QObject,
      * @brief  Get a group from the settings
      * @param  name  the name of the group
      */
+    const GeoSceneGroup* group( const QString& name ) const;
     GeoSceneGroup* group( const QString& name );
 
     /**
@@ -104,6 +105,7 @@ class GEODATA_EXPORT GeoSceneSettings : public QObject,
      * @brief  Get a property from the settings
      * @param  name  the name of the property
      */
+    const GeoSceneProperty* property( const QString& name ) const;
     GeoSceneProperty* property( const QString& name );
 
     /**
@@ -124,4 +126,4 @@ class GEODATA_EXPORT GeoSceneSettings : public QObject,
 
 }
 
-#endif // GEOSCENESETTINGS_H
+#endif
