@@ -9,8 +9,8 @@
 //
 
 
-#ifndef GPSLAYER_H
-#define GPSLAYER_H
+#ifndef MARBLE_GPSLAYER_H
+#define MARBLE_GPSLAYER_H
 
 #include "AbstractLayer.h"
 
@@ -22,6 +22,7 @@ namespace Marble
 class PositionTracking;
 class GpxFile;
 class GpxFileModel;
+class PluginManager;
 class Track;
 class Waypoint;
 
@@ -29,7 +30,8 @@ class GpsLayer : public AbstractLayer
 {
 
  public:
-    explicit GpsLayer( GpxFileModel *fileModel, QObject *parent =0 );
+    explicit GpsLayer( GpxFileModel *fileModel,
+                       QObject *parent =0 );
     ~GpsLayer();
     virtual void paintLayer( ClipPainter *painter, 
                              const QSize &canvasSize,
