@@ -8,31 +8,29 @@
 // Copyright 2007      Andrew Manson  <g.real.ate@gmail.com>
 //
 
-#ifndef ROUTECONTAINER_H
-#define ROUTECONTAINER_H
+#ifndef MARBLE_ROUTECONTAINER_H
+#define MARBLE_ROUTECONTAINER_H
 
 
 #include "AbstractLayerContainer.h"
 
 
+namespace Marble
+{
+
 /**
  * @brief holds a collection of Routes
  */
 class RouteContainer : public virtual AbstractLayerContainer
 {
  public:
-     /*
-     virtual void draw ( ClipPainter *painter, const QPoint &point);
-     */
-    /*
-     virtual void draw( ClipPainter *painter, 
-                        const QSize &canvasSize, double radius,
-                        Quaternion invRotAxis );*/
     
      virtual void draw( ClipPainter *painter, 
                         const QSize &canvasSize,
-                        ViewParams *viewParams,
-                        const BoundingBox &box );
+                        ViewParams *viewParams );
+     using AbstractLayerContainer::draw;
 };
 
+}
+
 #endif
