@@ -8,8 +8,8 @@
 // Copyright 2007      Andrew Manson    <g.real.ate@gmail.com>
 // Copyright 2008      Jens-Michael Hoffmann <jensmh@gmx.de>
 //
-#ifndef WAYPOINT_H
-#define WAYPOINT_H
+#ifndef MARBLE_WAYPOINT_H
+#define MARBLE_WAYPOINT_H
 
 #include "AbstractLayerData.h"
 #include "GpsElement.h"
@@ -20,7 +20,7 @@ namespace Marble
 {
 
 /**
- * @brief representaion of a GPS Waypoint.
+ * @brief representation of a GPS Waypoint.
  * 
  * A Waypoint is a point of interest, or named feature on a map.
  */
@@ -39,7 +39,7 @@ class Waypoint : public AbstractLayerData, public GpsElement
     Waypoint( qreal lat, qreal lon );
     
     /**
-     * @brief Constructor froim a geopoint object
+     * @brief Constructor from a geopoint object
      * @param position the geopoint that will be the position of this
      *                 waypoint
      */
@@ -260,7 +260,7 @@ class Waypoint : public AbstractLayerData, public GpsElement
     qreal m_hdop;
     
     /**
-     * @brief Vertical dilution of presision.
+     * @brief Vertical dilution of precision.
      */
     qreal m_vdop;
     
@@ -284,4 +284,4 @@ class Waypoint : public AbstractLayerData, public GpsElement
 
 }
 
-#endif //WAYPOINT_H
+#endif
