@@ -1,6 +1,6 @@
 /*
     Copyright 2008 Henry de Valence <hdevalence@gmail.com>
-    
+
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
@@ -14,28 +14,30 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public 
+    You should have received a copy of the GNU Lesser General Public
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef MARBLEABSTRACTRUNNER_H
-#define MARBLEABSTRACTRUNNER_H
+#ifndef MARBLE_MARBLEABSTRACTRUNNER_H
+#define MARBLE_MARBLEABSTRACTRUNNER_H
 
 #include "GeoDataFeature.h"
 #include "GeoDataPlacemark.h"
 
-#include <QThread>
-#include <QVector>
+#include <QtCore/QThread>
+#include <QtCore/QVector>
 
+class QAbstractItemModel;
 class QString;
 
 namespace Marble
 {
 
+class MarbleMap;
 class GeoDataPlacemark;
 
 /**
- * This class is the base class for all Marble Runners. 
+ * This class is the base class for all Marble Runners.
  */
 class MarbleAbstractRunner : public QThread
 {
@@ -45,18 +47,15 @@ public:
      * Constructor; note that @p parent should be 0 in order to move the
      * thread object into its own thread.
      */
-    MarbleAbstractRunner(QObject *parent = 0);
-    /**
-     * Destructor.
-     */
-    virtual ~MarbleAbstractRunner();
+    explicit MarbleAbstractRunner(QObject *parent = 0);
     /**
      * This function gives the  icon for this runner
      * @return the icon of the runner
      */
     virtual GeoDataFeature::GeoDataVisualCategory category() const;
 
-    void run(); 
+    void setMap(MarbleMap * map);
+    MarbleMap * map();
 
 public slots:
     /**
@@ -70,6 +69,8 @@ public slots:
 
 protected:
     QString m_input;
+    QAbstractItemModel * m_placemarkModel;
+    MarbleMap * m_map;
 
 signals:
     /**
