@@ -25,10 +25,10 @@
 #include <KAction>
 #include <KActionCollection>
 
-LessonView::LessonView(Editor * parent) :ContainerView(parent)
-{
-//     setContextMenuPolicy(Qt::CustomContextMenu);
+using namespace Editor;
 
+LessonView::LessonView(EditorWindow * parent) :ContainerView(parent)
+{
     KAction *actionNewLesson = new KAction(this);
     parent->actionCollection()->addAction("new_lesson", actionNewLesson);
     actionNewLesson->setText(i18n("New Lesson"));
@@ -41,7 +41,7 @@ LessonView::LessonView(Editor * parent) :ContainerView(parent)
     parent->actionCollection()->addAction("rename_lesson", actionRenameLesson);
     actionRenameLesson->setText(i18n("Rename Lesson"));
     actionRenameLesson->setIcon(KIcon("edit-rename"));
-    actionRenameLesson->setWhatsThis(i18n("Rename the selected lesson"));
+//    actionRenameLesson->setWhatsThis(i18n("Rename the selected lesson"));
     actionRenameLesson->setToolTip(actionRenameLesson->whatsThis());
     actionRenameLesson->setStatusTip(actionRenameLesson->whatsThis());
 
