@@ -19,7 +19,8 @@
 #include "containerview.h"
 #include "lessonmodel.h"
 
-class Editor;
+namespace Editor {
+    class EditorWindow;
 
 /**
  * View for the lesson list.
@@ -30,7 +31,7 @@ class LessonView : public ContainerView
     Q_OBJECT
 
 public:
-    LessonView(Editor *parent);
+    LessonView(EditorWindow *parent);
 
     /** Set the model for the view.
      * @param model the model */
@@ -61,7 +62,11 @@ protected slots:
     void currentChanged( const QModelIndex & current, const QModelIndex & previous );
 
 private:
+    virtual void setModel(ContainerModel *model) { Q_UNUSED(model) }
+    virtual void setModel(QAbstractItemModel *model) { Q_UNUSED(model) }
+
     LessonModel *m_model;
 };
+}
 
 #endif
